@@ -5,6 +5,7 @@ import atexit
 from contextlib import suppress
 from enum import Enum
 import getpass
+import logging
 import os
 import time
 from typing import ClassVar
@@ -24,6 +25,7 @@ from distributed.utils import (
     TimeoutError,
     format_dashboard_link,
 )
+from kubernetes_asyncio.client.exceptions import ApiException
 
 from dask_kubernetes.common.auth import ClusterAuth
 
@@ -34,6 +36,8 @@ from dask_kubernetes.common.networking import (
 )
 from dask_kubernetes.common.utils import get_current_namespace
 
+logger = logging.getLogger(__name__)
+
 
 class CreateMode(Enum):
     CREATE_ONLY = "CREATE_ONLY"
@@ -98,6 +102,9 @@ class KubeCluster(Cluster):
     custom_cluster_spec: str | dict (optional)
         Path to a YAML manifest or a dictionary representation of a ``DaskCluster`` resource object which will be
         used to create the cluster instead of generating one from the other keyword arguments.
+    scheduler_forward_port: int (optional)
+        The port to use when forwarding the scheduler dashboard. Will utilize a random port by default
+
     **kwargs: dict
         Additional keyword arguments to pass to LocalCluster
 
@@ -153,6 +160,7 @@ class KubeCluster(Cluster):
         resource_timeout=None,
         scheduler_service_type=None,
         custom_cluster_spec=None,
+        scheduler_forward_port=None,
         **kwargs,
     ):
 
@@ -196,6 +204,9 @@ class KubeCluster(Cluster):
         self.scheduler_service_type = dask.config.get(
             "kubernetes.scheduler-service-type", override_with=scheduler_service_type
         )
+        self.scheduler_forward_port = dask.config.get(
+            "kubernetes.scheduler-forward-port", override_with=scheduler_forward_port
+        )
 
         if self._custom_cluster_spec:
             if isinstance(self._custom_cluster_spec, str):
@@ -234,13 +245,22 @@ class KubeCluster(Cluster):
             await self._connect_cluster()
         elif not cluster_exists and self.create_mode == CreateMode.CONNECT_ONLY:
             raise ValueError(
-                f"Cluster {self.name} doesn't and create mode is '{CreateMode.CONNECT_ONLY}'"
+                f"Cluster {self.name} doesn't already exist and create "
+                f"mode is '{CreateMode.CONNECT_ONLY}'"
             )
         else:
             await self._create_cluster()
 
         await super()._start()
 
+    def __await__(self):
+        async def _():
+            if self.status == Status.created:
+                await self._start()
+            return self
+
+        return _().__await__()
+
     async def _create_cluster(self):
         if self.shutdown_on_close is None:
             self.shutdown_on_close = True
@@ -285,11 +305,15 @@ class KubeCluster(Cluster):
             scheduler_address = await self._get_scheduler_address()
             await wait_for_scheduler_comm(scheduler_address)
             self.scheduler_comm = rpc(scheduler_address)
+            local_port = self.scheduler_forward_port
+            if local_port:
+                local_port = int(local_port)
             dashboard_address = await get_scheduler_address(
                 f"{self.name}-scheduler",
                 self.namespace,
                 port_name="http-dashboard",
                 port_forward_cluster_ip=self.port_forward_cluster_ip,
+                local_port=local_port,
             )
             self.forwarded_dashboard_port = dashboard_address.split(":")[-1]
 
@@ -316,11 +340,15 @@ class KubeCluster(Cluster):
             scheduler_address = await self._get_scheduler_address()
             await wait_for_scheduler_comm(scheduler_address)
             self.scheduler_comm = rpc(scheduler_address)
+            local_port = self.scheduler_forward_port
+            if local_port:
+                local_port = int(local_port)
             dashboard_address = await get_scheduler_address(
                 service_name,
                 self.namespace,
                 port_name="http-dashboard",
                 port_forward_cluster_ip=self.port_forward_cluster_ip,
+                local_port=local_port,
             )
             self.forwarded_dashboard_port = dashboard_address.split(":")[-1]
 
@@ -547,13 +575,21 @@ class KubeCluster(Cluster):
         if self.shutdown_on_close:
             async with kubernetes.client.api_client.ApiClient() as api_client:
                 custom_objects_api = kubernetes.client.CustomObjectsApi(api_client)
-                await custom_objects_api.delete_namespaced_custom_object(
-                    group="kubernetes.dask.org",
-                    version="v1",
-                    plural="daskclusters",
-                    namespace=self.namespace,
-                    name=self.name,
-                )
+                try:
+                    await custom_objects_api.delete_namespaced_custom_object(
+                        group="kubernetes.dask.org",
+                        version="v1",
+                        plural="daskclusters",
+                        namespace=self.namespace,
+                        name=self.name,
+                    )
+                except ApiException as e:
+                    if e.reason == "Not Found":
+                        logger.warning(
+                            "Failed to delete DaskCluster, looks like it has already been deleted."
+                        )
+                    else:
+                        raise
             start = time.time()
             while (await self._get_cluster()) is not None:
                 if time.time() > start + timeout:
